<?php
/**
 * Plugin Name:       Attribute Price Markup and Discount
 * Requires Plugins:  woocommerce
 * Plugin URI:        https://woocommerce.com/products/addify-attribute-price-markup-discount/
 * Description:       Adjust the prices of your product variations based on attributes and terms.
 * Version:           1.0.0
 * Author:            Addify
 * Developed By:      Addify
 * Author URI:        https://woocommerce.com/vendor/addify/
 * Support:           https://woocommerce.com/vendor/addify/
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Domain Path:       /languages
 * Text Domain:       addify-attribute-price-markup-discount
 * WC requires at least: 4.0
 * WC tested up to: 9.*.*
 * Requires at least: 6.5
 * Tested up to: 6.*.*
 * Requires PHP: 7.4
 *
 * @package addify-attribute-m-a-d
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Af_Attribute_Markup_And_Discount' ) ) {

	/**
	 * Main class of Plugin
	 */
	class Af_Attribute_Markup_And_Discount {

		/**
		 * Constructor of class.
		 *
		 * @return void
		 */
		public function __construct() {

			$this->af_amad_global_const();
			add_action( 'init', array( $this, 'afadcod_register_post_type_and_files_added' ) );
			add_action('before_woocommerce_init', array( $this, 'addify_amad_HOPS_Compatibility' ));
			add_action( 'plugins_loaded', array( $this, 'addify_amad_is_multiple_check' ) );
		}
		
		public function afadcod_register_post_type_and_files_added() {
			if ( defined( 'WC_PLUGIN_FILE' ) ) {
				$this->afadcod_register_post_type();
				add_action( 'wp_loaded', array( $this, 'addify_amad_load_text_domain' ) );
				include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/general-functions/addify-amad-general-function.php';
				if ( is_admin() ) {
					include_once ADDIFY_AMAD_PLUGIN_DIR . '/includes/admin/class-addify-amad-admin.php';
				} else {
					include_once ADDIFY_AMAD_PLUGIN_DIR . '/includes/front/class-addify-amad-front.php';
				}

				if (amad_is_need_to_include_ajax_file()) {
					include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/ajax-controller/afamad-ajax-front-controller.php';
				}
			}
		}
		public function addify_amad_load_text_domain() {
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'addify-attribute-price-markup-discount', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			}
		}
		public function addify_amad_is_multiple_check() {
			if ( ! is_multisite() && ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
				add_action( 'admin_notices', array( $this, 'af_amad_check_wocommerce' ));
			}
		}


		public function af_amad_check_wocommerce() {

			deactivate_plugins( __FILE__ );
			$amad_woo_check = '<div id="message" class="error">
				<p><strong>' . __( 'Attribute Price Markup and Discount plugin is inactive.', 'addify-attribute-price-markup-discount' ) . '</strong> The <a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce plugin</a> ' . __( 'must be active for this plugin to work. Please install &amp; activate WooCommerce.', 'addify-attribute-price-markup-discount' ) . ' »</p></div>';
			echo wp_kses_post( $amad_woo_check );
		}

		public function addify_amad_HOPS_Compatibility() {
			if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}

		/**
		 * Constructor of class.
		 *
		 * @return void
		 */
		public function af_amad_global_const() {

			if ( ! defined( 'ADDIFY_AMAD_URL' ) ) {
				define( 'ADDIFY_AMAD_URL', plugin_dir_url( __FILE__ ) );
			}

			if ( ! defined( 'ADDIFY_AMAD_BASENAME' ) ) {
				define( 'ADDIFY_AMAD_BASENAME', plugin_basename( __FILE__ ) );
			}

			if ( ! defined( 'ADDIFY_AMAD_PLUGIN_DIR' ) ) {
				define( 'ADDIFY_AMAD_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
			}
		}

		/**
		 * Register custom post type for extra fees.
		 *
		 * @return void
		 */
		public function afadcod_register_post_type() {

			$labels = array(
				'name'                => esc_html__( 'Attribute Price Markup and Discount', 'addify-attribute-price-markup-discount' ),
				'singular_name'       => esc_html__( 'Attribute Markup and Discount', 'addify-attribute-price-markup-discount' ),
				'add_new'             => esc_html__( 'Add New Rule ', 'addify-attribute-price-markup-discount' ),
				'add_new_item'        => esc_html__( 'Add New Rule', 'addify-attribute-price-markup-discount' ),
				'edit_item'           => esc_html__( 'Edit Rule', 'addify-attribute-price-markup-discount' ),
				'new_item'            => esc_html__( 'New Rule', 'addify-attribute-price-markup-discount' ),
				'view_item'           => esc_html__( 'View Rule', 'addify-attribute-price-markup-discount' ),
				'search_items'        => esc_html__( 'Search  Rule', 'addify-attribute-price-markup-discount' ),
				'exclude_from_search' => true,
				'not_found'           => esc_html__( 'No rule found', 'addify-attribute-price-markup-discount' ),
				'not_found_in_trash'  => esc_html__( 'No rule found in trash', 'addify-attribute-price-markup-discount' ),
				'parent_item_colon'   => '',
				'all_items'           => esc_html__( 'Attribute Price', 'addify-attribute-price-markup-discount' ),
				'menu_name'           => esc_html__( 'Attribute Price', 'addify-attribute-price-markup-discount' ),
				'attributes'          => esc_html__( 'Rule Priority', 'addify-attribute-price-markup-discount' ),
			);

			$args1 = array(
				'labels'             => $labels,
				'menu_icon'          => plugins_url( 'assets/images/set.png', __FILE__ ),
				'public'             => false,
				'publicly_queryable' => true,
				'show_ui'            => true,
				'show_in_menu'       => ( 'woocommerce' ),
				'query_var'          => true,
				'capability_type'    => 'post',
				'has_archive'        => true,
				'hierarchical'       => false,
				'menu_position'      => 30,
				'rewrite'            => array(
					'slug'       => 'addify_amad_cpt',
					'with_front' => false,
				),
				'supports'           => array( 'title', 'page-attributes' ),

			);
			register_post_type( 'addify_amad_cpt', $args1 );
		}
		
		public function afadcod_plugin_settings( $settings ) {
			$settings[] = '<a href="' . admin_url('admin.php?page=addify_advance_cod') . '">Settings</a>';
			return $settings;
		}
	}

	new Af_Attribute_Markup_And_Discount();
}
