<?php
/**
 * Admin file of Module.
 *
 * Manage all settings and actions of admin.
 *
 * @package  addify-addify-amad
 * @version  1.1.0
 */

 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
if ( ! class_exists( 'Addify_Amad_Admin' ) ) {
	/**
	 *  Class for admin.
	 */
	class Addify_Amad_Admin {

		public function __construct() {
			
			add_action( 'admin_enqueue_scripts', array( $this, 'af_amad_admin_enqueue_css_js' ) , 10 );
			add_action( 'admin_init', array( $this, 'amad_add_setting_files' ) , 10 );
			add_action( 'add_meta_boxes', array( $this, 'addify_amad_meta_boxes' ) , 10 );
			add_action( 'save_post_addify_amad_cpt', array( $this, 'addify_amad_save_metadata' ) , 10, 2 );

			// Admin all fees Table columns.
			add_filter( 'manage_addify_amad_cpt_posts_columns', array( $this, 'addify_amad_add_posts_columns' )  );
			add_action( 'manage_addify_amad_cpt_posts_custom_column', array( $this, 'addify_amad_insert_data_in_colmuns' ) , 10, 2 );

			// Ajax Search Hooks.
			add_action( 'wp_ajax_afamad_search_products', array( $this, 'afamad_search_products' ));
			add_action( 'woocommerce_after_edit_attribute_fields', array( $this, 'addify_amad_add_data_in_attributes_edit' ) , 20, 2 );
		}

		/**
		 * Enqueue admin assets.
		 *
		 * @return void
		 */
		public function addify_amad_add_data_in_attributes_edit() {
			include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/admin/attribute-level-settings.php';
		}
		public function addify_amad_add_posts_columns( $columns ) {
			unset( $columns['date'] );
			
			$columns['rule_enb']                            = esc_html__( 'Rule Enable/Disable', 'addify-attribute-price-markup-discount' );
			$columns['rule_date']                           = esc_html__( 'From - Till', 'addify-attribute-price-markup-discount' );
			$columns['rule_apply_on_regular_or_sale_price'] = esc_html__( 'Rule Apply On', 'addify-attribute-price-markup-discount' );
			$columns['markup_markdown']                     = esc_html__( 'Adjustment Type', 'addify-attribute-price-markup-discount' );
			$columns['fixed_or_percentage']                 = esc_html__( 'Type Of Discount', 'addify-attribute-price-markup-discount' );
			$columns['amount']                              = esc_html__( 'Amount', 'addify-attribute-price-markup-discount' );
			$columns['menu_order']                          = esc_html__( 'Rule Priority', 'addify-attribute-price-markup-discount' );
			$columns['date']                                = esc_html__( 'Date', 'addify-attribute-price-markup-discount' );

			return $columns;
		}
		public function addify_amad_insert_data_in_colmuns( $column, $post_id ) {
			if ( 'rule_enb' == $column ) {
				$rule_enb = json_decode(get_post_meta( $post_id, 'rule_enb', true ));
				$rule_enb = '1' == $rule_enb ? 'Enable' : 'Disable' ;
				echo esc_attr($rule_enb);

			} elseif ( 'rule_date' === $column ) {
				$rule_date      = get_post_meta( $post_id, 'rule_date', true );
				$rule_date      = is_array($rule_date) ? $rule_date : array();
				$rule_date_from = isset($rule_date[0]) ? $rule_date[0] : '';
				$rule_date_till = isset($rule_date[1]) ? $rule_date[1] : '';
				echo esc_attr($rule_date_from . ' - ' . $rule_date_till);

			} elseif ( 'taxable' === $column ) {
				$tax = get_post_meta( $post_id, 'afadcod_enable_tax', true );
				echo esc_html( 'yes' === $tax ? 'Yes' : 'No' );
				
			} elseif ( 'rule_apply_on_regular_or_sale_price' === $column ) {
			$rule_apply_on_regular_or_sale_price = get_post_meta( $post_id, 'rule_apply_on_regular_or_sale_price', true );

				switch ( $rule_apply_on_regular_or_sale_price ) {
					case '':
							esc_html_e( 'Not set', 'addify-attribute-price-markup-discount' );
						break;
					case 'regular_price':
						esc_html_e( 'Sale Price', 'addify-attribute-price-markup-discount' );
						break;
					case 'sale_price':
					esc_html_e( 'Regular Price', 'addify-attribute-price-markup-discount' );
						break;
				}

			} elseif ('markup_markdown' == $column ) {
			$markup_markdown = get_post_meta( $post_id, 'markup_markdown', true );

				switch ( $markup_markdown ) {
					case '':
							esc_html_e( 'Not set', 'addify-attribute-price-markup-discount' );
						break;
					case 'markup':
						esc_html_e( 'Markup', 'addify-attribute-price-markup-discount' );
						break;
					case 'markdown':
					esc_html_e( 'Markdown', 'addify-attribute-price-markup-discount' );
						break;
				}

			} elseif ('fixed_or_percentage' == $column ) {
			$fixed_or_percentage = get_post_meta( $post_id, 'fixed_or_percentage', true );

				switch ( $fixed_or_percentage ) {
					case '':
							esc_html_e( 'Not set', 'addify-attribute-price-markup-discount' );
						break;
					case 'fixed':
						esc_html_e( 'Fixed', 'addify-attribute-price-markup-discount' );
						break;
					case 'percentage':
					esc_html_e( 'Percentage', 'addify-attribute-price-markup-discount' );
						break;
				}

			} elseif ('amount' == $column ) {
			$amount = get_post_meta( $post_id, 'amount', true );

			} elseif ('menu_order' == $column ) {
			$post       = get_post($post_id); 
			$menu_order = $post->menu_order; 
			echo esc_attr($menu_order);
			}
		}
		public function addify_amad_meta_boxes() {
			// Meta box for extra fee.
			add_meta_box(
				'rules-settings',
				esc_html__( 'Rules Settings', 'addify-attribute-price-markup-discount' ),
				array( $this, 'afamad_rule_settings_metadata' ),
				'addify_amad_cpt'
			);
			add_meta_box(
				'restrictions-section',
				esc_html__( 'Restrictions Section', 'addify-attribute-price-markup-discount' ),
				array( $this, 'afamad_restriction_section_metadata' ),
				'addify_amad_cpt'
			);
			add_meta_box(
				'markup-discount-section',
				esc_html__( 'Markup / Discount Section', 'addify-attribute-price-markup-discount' ),
				array( $this, 'afamad_mark_discount_section_metadata' ),
				'addify_amad_cpt'
			);
			add_meta_box(
				'priority-note',
				esc_html__( 'Note', 'addify-attribute-price-markup-discount' ),
				array( $this, 'afamad_priority_note_metadata' ),
				'addify_amad_cpt',
				'side',
				'default'
			);
		}
		public function afamad_priority_note_metadata() {
			?>
				<h4><?php esc_html_e('Rule Priority Order', 'addify-attribute-price-markup-discount'); ?></h4>
				<ol>
					<li><?php esc_html_e('Rule Level Pricing', 'addify-attribute-price-markup-discount'); ?></li>
					<li><?php esc_html_e('Products > Attributes > Term Level Pricing', 'addify-attribute-price-markup-discount'); ?></li>
					<li><?php esc_html_e('Products > Attributes Level Pricing', 'addify-attribute-price-markup-discount'); ?></li>
				</ol>
			<?php
		}
		public function addify_amad_save_metadata( $post_id, $post = false ) {
			// Return if we're doing an auto save.
			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return;
			}

			$action           = filter_input(INPUT_GET, 'action', FILTER_SANITIZE_FULL_SPECIAL_CHARS);
			$exclude_statuses = array(
				'auto-draft',
				'trash',
			);

			if ( in_array( get_post_status($post_id), $exclude_statuses ) || is_ajax() || 'untrash' === $action ) {
				return;
			}
			include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/metaboxes/save-metaboxes-data.php';
		}
		public function amad_add_setting_files( $term ) {

			$attribute_taxonomies = wc_get_attribute_taxonomies();
			foreach ( $attribute_taxonomies as $attribute_taxonomy ) {
				$taxonomy = 'pa_' . $attribute_taxonomy->attribute_name;

				add_action( "{$taxonomy}_edit_form_fields", array( $this, 'afamad_term_data_in_edit' ) , 10, 2 );
				add_action( "edited_{$taxonomy}", array( $this, 'afamad_save_term_data_in_edit' ) , 10, 2 );
			}
		}
		public function afamad_term_data_in_edit( $term ) {
			include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/admin/terms-level-settings.php';
		}
		public function afamad_save_term_data_in_edit( $term_id ) {
			include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/admin/terms-level-data-saving.php';
		}
		public function afamad_rule_settings_metadata() {
			wp_nonce_field( 'afamad_nonce_action', 'afamad_nonce_field' );
			include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/metaboxes/rules-settings.php';
		} public function afamad_restriction_section_metadata() {
			include_once ADDIFY_AMAD_PLUGIN_DIR . 'includes/metaboxes/restriction-section.php';
		} public function afamad_mark_discount_section_metadata() {

			$post_id = get_the_id();
			include ADDIFY_AMAD_PLUGIN_DIR . 'includes/metaboxes/rule-restriction-table.php';
		}
		public function get_post_ids_by_parent_post_id( $post_type, $main_product_id = '', $parameter = array() ) {

			$aurg = array(
				'post_type'   => $post_type,
				'post_status' => 'publish',
				'post_parent' => $main_product_id,
				'fields'      => 'ids',
				'numberposts' => -1,
				'orderby'     => 'meta_value_num',
				'order'       => 'ASC',
			);
	
			if ( count( $parameter ) >= 1 ) {
				$aurg = array_merge( $aurg , $parameter);
	
			}
	
			$get_post_data = new WP_Query( $aurg );
			$get_post_data = $get_post_data->have_posts() ? $get_post_data->get_posts() : array();
			return $get_post_data;
		}//end get_post_ids_by_parent_post_id()

		public function afamad_search_products() {
			$nonce = isset( $_POST['nonce'] ) && '' !== $_POST['nonce'] ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : 0;

			if ( isset( $_POST['q'] ) && '' !== $_POST['q'] ) {
				if ( ! wp_verify_nonce( $nonce, 'afamad-ajax-nonce' ) ) {
					die( 'Failed ajax security check!' );
				}
				$pro = sanitize_text_field( wp_unslash( $_POST['q'] ) );
			} else {
				$pro = '';
			}

			$data_array = array();

			$args = array(
				'post_type'   => array( 'product' ),
				'post_status' => 'publish',
				'numberposts' => -1,
				's'           => $pro,
				'orderby'     => 'relevance',

			);
			$pros = get_posts( $args );
			if ( ! empty( $pros ) ) {
				foreach ( $pros as $proo ) {
					$title        = ( mb_strlen( $proo->post_title ) > 50 ) ? mb_substr( $proo->post_title, 0, 49 ) . '...' : $proo->post_title;
					$data_array[] = array( $proo->ID, $title ); // array( Post ID, Post Title ).
				}
			}

			echo wp_json_encode( $data_array );
			die();
		}
		public function insert_post( $post_type, $main_product_id = '' ) {

			$aurg = array(
				'post_type'   => $post_type,
				'post_status' => 'publish',
				'post_parent' => $main_product_id,
			);
	
			$new_post_id = wp_insert_post( $aurg );
			return $new_post_id;
		}//end insert_post()
		public function af_amad_admin_enqueue_css_js() {

			$current_screen_id = get_current_screen()->id;
			if ( 'addify_amad_cpt' == $current_screen_id || 'product_page_product_attributes' == $current_screen_id  ) {
		
				// Enqueue Styles.
				wp_enqueue_style( 'afamad-css-admin', ADDIFY_AMAD_URL . 'assets/css/admin.css', false, '1.0' );

				// Enqueue Select2 CSS
				wp_enqueue_style( 'select2-css', plugins_url( 'assets/css/select2.css', WC_PLUGIN_FILE ), array(), '5.7.2' );
				wp_enqueue_script( 'select2-js', plugins_url( 'assets/js/select2/select2.min.js', WC_PLUGIN_FILE ), array( 'jquery' ), '4.0.3', true );
				wp_enqueue_style('fontawesome-icons', ADDIFY_AMAD_URL . 'assets/fontawesome/css/all.min.css', array(), '6.0.0');

				// Enqueue Scripts.
				wp_enqueue_script( 'jquery');
				wp_enqueue_script( 'afamad-js-admin', ADDIFY_AMAD_URL . 'assets/js/admin.js', array( 'jquery' ), '1.0.0', false );

				

				ob_start();
				$ruleset_settings_template_row = ob_get_clean();

				ob_start();
				$this->af_am_group_templates ();

				$af_am_group_templates = ob_get_clean();

				ob_start();
				$this->af_am_add_row_templates ();

				$af_am_add_row_templates = ob_get_clean();

				// Localize the variables.
				$afamad_data = array(
					'admin_url'                     => admin_url( 'admin-ajax.php' ),
					'nonce'                         => wp_create_nonce( 'afamad-ajax-nonce' ),
					'ruleset_settings_template_row' => $ruleset_settings_template_row,
					'af_am_group_templates'         => $af_am_group_templates,
					'af_am_add_row_templates'       => $af_am_add_row_templates,

				);

				foreach ( wc_get_attribute_taxonomies() as $attribute_detail ) {
	
					ob_start();
					$this->af_am_child_gruop_id($attribute_detail->attribute_name);
					$result = ob_get_clean();
					$afamad_data[ $attribute_detail->attribute_name ] = $result;
				}

				wp_localize_script( 'afamad-js-admin', 'afamad_php_vars', $afamad_data );
			}

			wp_enqueue_script( 'afamad-js-admin', ADDIFY_AMAD_URL . 'assets/js/admin-for-term-hide.js', array( 'jquery' ), '1.0', false );
		}
		public function af_am_group_templates() {
			include ADDIFY_AMAD_PLUGIN_DIR . 'includes/admin/admin-table-rule-temp/admin-table-rule-group-temp.php';
		} public function af_am_add_row_templates() {
			include ADDIFY_AMAD_PLUGIN_DIR . 'includes/admin/admin-table-rule-temp/admin-table-rule-row-temp.php';
		} public function af_am_child_gruop_id( $taxonomy_name, $group_id = 'group_id', $child_id = 'child_id' ) {
			?>
	<select  name="af_select_attribute[<?php echo esc_attr($group_id); ?>][<?php echo esc_attr( $child_id); ?>][term][]" class="select_pro_terms af_select_attribute_groups af_select_attribute_values_array
													<?php
			echo esc_attr($group_id);
		echo esc_attr( $child_id);
													?>
	" multiple>
				<?php
		
				if ( taxonomy_exists( wc_attribute_taxonomy_name( $taxonomy_name ) ) ) {
					$get_taxonomy_val = get_terms( array(
						'taxonomy'   => wc_attribute_taxonomy_name( $taxonomy_name ),
						'orderby'    => 'name',
						'hide_empty' => false,
					) );
					foreach ( $get_taxonomy_val as $taxonomy_val_class_obj ) {
						?>
				<option value="<?php echo esc_attr( $taxonomy_val_class_obj->term_id ); ?>">

					<?php echo esc_attr( $taxonomy_val_class_obj->name ); ?>

				</option>

				<?php
					}
				}
				?>

	</select>	
			<?php
		}
	}
new Addify_Amad_Admin();

}
